Filters for manipulating data
=============================

The *filters* module provides some common filters for moving between proteins, roles, enzymes, and reactions. These
are accessory functions that you will want to use with your FBA work

Identifying reactions with/without proteins
-------------------------------------------

.. automodule:: PyFBA.filters.reactions_and_proteins
    :members:

Converting between roles and reactions and vice-versa
-----------------------------------------------------

.. automodule:: PyFBA.filters.roles_and_reactions
    :members:

